<?php
/**
 * Seiryuu functions and definitions
 *
 * @package Seiryuu
 */

if ( ! function_exists( 'seiryuu_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function seiryuu_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Seiryuu, use a find and replace
	 * to change 'seiryuu' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'seiryuu', get_template_directory() . '/languages' );

  /**
   * Set the content width based on the theme's design and stylesheet.
   */
  if ( ! isset( $content_width ) ) {
	  $content_width = 640; /* pixels */
  }
  
	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );
  
  // Let WordPress manage the <title> tag
  add_theme_support( 'title-tag' );
  
	// This theme uses two menus: a primary menu and a social media menu.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'seiryuu' ),
		'social'  => __( 'Social Media Menu', 'seiryuu' )
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See http://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside', 'image', 'video', 'quote', 'link',
	) );
	
	// Enable support for Featured Images
	add_theme_support( 'post-thumbnails' );
}
endif; // seiryuu_setup
add_action( 'after_setup_theme', 'seiryuu_setup' );

/**
 * Register widget area.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function seiryuu_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'seiryuu' ),
		'id'            => 'primary',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
}
add_action( 'widgets_init', 'seiryuu_widgets_init' );

if ( ! function_exists( 'seiryuu_excerpt_more' ) ) :
/**
 * Since we're using excerpts, let's make the link more interesting
 */
function seiryuu_excerpt_more( $more ) {
  global $post;
  
  $seiryuu_read_more = sprintf(
    '<span class="read-more"><a href="%1$s">%2$s</a></span>',
      esc_url( get_permalink( $post->ID ) ),
      __( 'Read More &raquo;', 'seiryuu' )
  );
  
  return $seiryuu_read_more;
}
endif;
add_filter( 'excerpt_more', 'seiryuu_excerpt_more' );

if ( ! function_exists( 'seiryuu_theme_options' ) ) :
/**
 * Add theme options to the Customizer
 */
function seiryuu_theme_options( $wp_customize ) {
  $wp_customize->add_section( 'se_footer_text', array(
    'title'       => __( 'Footer Text', 'seiryuu' ),
    'description' => __( 'Text entered in this form will appear in place of the default footer text. A limited amount of HTML may be used.', 'seiryuu' ),
    'priority'    => 35
  ) );
  
  $wp_customize->add_setting( 'seiryuu_theme_options[footer_text]', array(
    'default'           => '',
    'type'              => 'option',
    'capability'        => 'edit_theme_options',
    'sanitize_callback' => 'wp_kses'
  ) );
  
  $wp_customize->add_control( 'seiryuu_theme_options[footer_text]', array(
    'label'    => __( 'Footer Text', 'seiryuu' ),
    'section'  => 'se_footer_text',
    'settings' => 'seiryuu_theme_options[footer_text]',
    'type'     => 'text'
  ) );
}
endif;
add_action( 'customize_register', 'seiryuu_theme_options' );

/**
 * Check if Google fonts should be used by translators
 */
function seiryuu_fonts_url() {
  $seiryuu_fonts_url = '';
  $font_families = array();
  
  /* translators: If there are characters in your language that aren't supported by Radley, translate this to 'off'. Do not translate this into your own language. */
  $radley = _x( 'on', 'Use Radley font: on or off', 'seiryuu' );
  
  if ( 'off' !== $radley) :
    $font_families[] = 'Radley:400,400italic,700,700italic';
  endif;
 
  $query_args = array(
    'family' => urlencode( implode( '|', $font_families ) ),
    'subset' => urlencode( 'latin,latin-ext' ),
  );
 
  $seiryuu_fonts_url = add_query_arg( $query_args, '//fonts.googleapis.com/css' );
  return $seiryuu_fonts_url;
}

/**
 * Enqueue scripts and styles.
 */
function seiryuu_scripts() {
	if ( is_child_theme() ) {
		wp_enqueue_style( 'parent-style', get_stylesheet_uri() );
	}
	
	wp_enqueue_style( 'seiryuu-style', get_stylesheet_uri() );
  wp_enqueue_style( 'seiryuu-fonts', seiryuu_fonts_url() );
  wp_enqueue_style( 'seiryuu-genericons', get_template_directory_uri() . '/inc/genericons/genericons/genericons.css' );
  

  if ( ! is_admin() ) {
	  wp_enqueue_script( 'masonry' );
	  wp_enqueue_script( 'seiryuu-functions', get_template_directory_uri() . '/js/functions.js', array( 'jquery' ), null, true );
  }

	wp_enqueue_script( 'seiryuu-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'seiryuu_scripts' );

if ( ! function_exists( 'seiryuu_author_to_comment_reply' ) ) :
/**
 * Display the author's first name when replying to a comment
 */
function seiryuu_author_to_comment_reply( $link, $args, $comment ) {
  $comment = get_comment( $comment );
 
  // If no comment author is blank, use 'Anonymous'
  if ( empty( $comment->comment_author ) ) :
    if ( ! empty( $comment->user_id ) ) :
      $user = get_userdata( $comment->user_id );
      $author = $user->user_login;
    else :
      $author = __( 'Anonymous', 'seiryuu' );
    endif;
  else :
    $author = $comment->comment_author;
  endif;
 
  // If the user provided more than a first name, use only first name
  if ( strpos( $author, ' ' ) ) :
    $author = substr( $author, 0, strpos( $author, ' ' ) ) ;
  endif;
 
  // Replace Reply Link with "Reply to <Author First Name>"
  $reply_link_text = $args['reply_text'];
  $link = str_replace( $reply_link_text, __( 'Reply to', 'seiryuu' ) . ' ' . $author, $link );
 
  return $link;
}
add_filter( 'comment_reply_link', 'seiryuu_author_to_comment_reply', 10, 4 );
endif;

if ( ! function_exists( 'seiryuu_comment_display' ) ) :
/**
 * Custom function to display comments. This can be overridden in your child theme, if desired.
 */
function seiryuu_comment_display( $comment, $args, $depth ) {
  $GLOBALS['comment'] = $comment;
  global $post;
  
  if ( 'pingback' == $comment->comment_type || 'trackback' == $comment->comment_type ) : ?>
    <li id="div-comment-<?php comment_ID(); ?>" <?php comment_class(); ?>>
      <article class="pingback-body">
        <div class="pingback-content">
          <?php _e( 'PINGBACK: ', 'seiryuu' ); ?>
          <cite><?php comment_author_link(); ?></cite>
        </div>
        
        <footer class="pingback-edit">
          <?php edit_comment_link( __( 'Edit', 'seiryuu' ) ); ?>
        </footer>
      </article>
    </li>
  <?php else : ?>
    <li <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ); ?>>
      <article id="comment-<?php comment_ID(); ?>" class="comment-body">
        <header class="comment-header">
          <div class="comment-avatar">
            <?php
            if ( '0' != $args['avatar_size'] ) :
              echo get_avatar( $comment, $args['avatar_size'] );
            endif;
            ?>
          </div>
          
          <div class="comment-meta">
            <cite class="fn"><?php echo get_comment_author_link(); ?></cite>
            <?php /* translators: 1: comment date, 2: comment time */ ?>
            <a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>" class="comment-time"><time datetime="<?php comment_time( 'c' ); ?>"><?php printf( _x( '%1$s, %2$s', '1: date, 2: time', 'seiryuu' ),
              get_comment_date(), /* %1$s */
              get_comment_time() /* %2$s */
            ); ?></time></a>
          </div>
        </header>
        
        <section class="comment-content">
          <?php
          if ( '0' == $comment->comment_approved ) : ?>
            <p><em><?php _e( 'Your comment is awaiting moderation.', 'seiryuu' ); ?></em></p>
          <?php endif; ?>
          
          <p><?php comment_text(); ?></p>
        </section>
        
        <footer class="comment-footer">
          <ul>
            <?php 
            comment_reply_link( array_merge( $args, array(
              'add_below' => 'comment',
              'depth'     => $depth,
              'max_depth' => $args['max_depth'],
              'before'    => '<li class="comment-reply">',
              'after'     => '</li>',
            ) ) );
            ?>
            
            <?php edit_post_link( __( 'Edit', 'seiryuu' ), '<li class="comment-edit">', '</li>' ); ?>
          </ul>
        </footer>
        
        <?php if ( $comment->user_id === $post->post_author ) : ?>
          <div class="ribbon-wrapper">
            <div class="ribbon">
              <span><?php _e( 'Author', 'seiryuu' ); ?></span>
            </div>
          </div>
        <?php endif; ?>
      </article>
    </li>
  <?php endif; ?>
<?php }
endif; // end if ! function_exists

/**
 * Filter body_class() for the full-width page template
 */
function seiryuu_full_width_class( $classes ) {
	if ( ! is_active_sidebar( 'primary' ) || is_page_template( 'page-full-width.php' ) || is_404() ) {
		$classes[] = 'full-width';
	}
	
	return $classes;
}
add_filter( 'body_class', 'seiryuu_full_width_class' );

/**
 * Add editor styles
 */
function seiryuu_add_editor_styles() {
  add_editor_style( array( 'editor-style.css', seiryuu_fonts_url() ) );
}
add_action( 'after_setup_theme', 'seiryuu_add_editor_styles' );

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';
