<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Seiryuu
 */

if ( ! function_exists( 'seiryuu_paging_nav' ) ) :
/**
 * Display the number of pages instead of just older and newer
 */
function seiryuu_paging_nav() {
	// Don't print empty markup if there's only one page.
	if ( $GLOBALS['wp_query']->max_num_pages < 2 ) {
		return;
	}

	$paged        = get_query_var( 'paged' ) ? intval( get_query_var( 'paged' ) ) : 1;
	$pagenum_link = html_entity_decode( get_pagenum_link() );
	$query_args   = array();
	$url_parts    = explode( '?', $pagenum_link );

	if ( isset( $url_parts[1] ) ) {
		wp_parse_str( $url_parts[1], $query_args );
	}

	$pagenum_link = remove_query_arg( array_keys( $query_args ), $pagenum_link );
	$pagenum_link = trailingslashit( $pagenum_link ) . '%_%';

	$format  = $GLOBALS['wp_rewrite']->using_index_permalinks() && ! strpos( $pagenum_link, 'index.php' ) ? 'index.php/' : '';
	$format .= $GLOBALS['wp_rewrite']->using_permalinks() ? user_trailingslashit( 'page/%#%', 'paged' ) : '?paged=%#%';

	// Set up paginated links.
	$links = paginate_links( array(
		'base'     => $pagenum_link,
		'format'   => $format,
		'total'    => $GLOBALS['wp_query']->max_num_pages,
		'current'  => $paged,
		'mid_size' => 1,
		'add_args' => array_map( 'urlencode', $query_args ),
		'prev_text' => _x( 'Prev', 'abbreviation for previous', 'seiryuu' ),
		'next_text' => __( 'Next', 'seiryuu' ),
	) );

	if ( $links ) :

	?>
	    <nav class="navigation paging-navigation" role="navigation">
	    	<h1 class="screen-reader-text"><?php _e( 'Posts navigation', 'seiryuu' ); ?></h1>
	    	<div class="pagination loop-pagination">
	    		<?php echo $links; ?>
	    	</div><!-- .pagination -->
	    </nav><!-- .navigation -->
	<?php
	endif;
}
endif;

if ( ! function_exists( 'seiryuu_post_nav' ) ) :
/**
 * Display navigation to next/previous post when applicable.
 */
function seiryuu_post_nav() {
	// Don't print empty markup if there's nowhere to navigate.
	$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
	$next     = get_adjacent_post( false, '', false );

	if ( ! $next && ! $previous ) {
		return;
	}
	?>
	<nav class="navigation post-navigation" role="navigation">
		<h1 class="screen-reader-text"><?php _e( 'Post navigation', 'seiryuu' ); ?></h1>
		<div class="nav-links">
		  <?php previous_post_link( '<div class="nav-previous"><span>Previous Post</span>%link</div>', '%title' ); ?>
      <?php next_post_link( '<div class="nav-next"><span>Next Post</span>%link</div>', '%title' ); ?>
		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}
endif;

if ( ! function_exists( 'seiryuu_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function seiryuu_posted_on() {
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() )
	);

	$posted_on = sprintf(
  	/* translators: this is the post date */
		_x( '%s', 'post date', 'seiryuu' ),
		'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
	);

  if ( ! is_author() ) :
	  $byline = sprintf(
    	/* translators: this is the author byline */
	    _x( 'by %s', 'author byline', 'seiryuu' ),
	    '<a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a>'
    );
  
    echo '<span class="posted-on">' . $posted_on . '</span><span class="byline"> ' . $byline . '</span>';
  else :
    echo '<span class="posted-on">' . $posted_on . '</span>';
  endif;

}
endif;

if ( ! function_exists( 'seiryuu_entry_footer' ) ) :
/**
 * Prints HTML with meta information for the categories and tags.
 */
function seiryuu_entry_footer() {
  echo '<ul>';
	// Hide category and tag text for pages.
	if ( 'post' == get_post_type() ) {  	
		/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list( __( ', ', 'seiryuu' ) );
		if ( $categories_list && seiryuu_categorized_blog() ) {
			printf( '<li class="cat-links">' . '%s' . '</li>', $categories_list );
		}

		/* translators: used between list items, there is a space after the comma */
		$tags_list = get_the_tag_list( '', __( ', ', 'seiryuu' ) );
		if ( $tags_list ) {
			printf( '<li class="tags-links">' . '%s' . '</li>', $tags_list );
		}
	}

	edit_post_link( __( 'Edit', 'seiryuu' ), '<li class="edit-link">', '</li>' );
	echo '</ul>';
}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function seiryuu_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'seiryuu_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,

			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'seiryuu_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so seiryuu_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so seiryuu_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in seiryuu_categorized_blog.
 */
function seiryuu_category_transient_flusher() {
	// Like, beat it. Dig?
	delete_transient( 'seiryuu_categories' );
}
add_action( 'edit_category', 'seiryuu_category_transient_flusher' );
add_action( 'save_post',     'seiryuu_category_transient_flusher' );
